@@ -92,6 +92,8 @@ import com.openexchange.imap.notify.internal.IMAPNotifierRegistry;
 import com.openexchange.imap.ping.IMAPCapabilityAndGreetingCache;
 import com.openexchange.imap.services.IMAPServiceRegistry;
 import com.openexchange.java.Charsets;
+import com.openexchange.java.StringAllocator;
+import com.openexchange.log.Log;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.Protocol;
 import com.openexchange.mail.api.IMailFolderStorage;
@@ -879,6 +881,22 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
             maxCount = getMaxCount();
             try {
                 imapStore = new AccessedIMAPStore(this, connectIMAPStore(maxCount > 0), imapSession);
+                if (DEBUG) {
+                    final String lineSeparator = System.getProperty("line.separator");
+                    final StringAllocator sb = new StringAllocator(1024);
+                    sb.append(lineSeparator).append(lineSeparator);
+                    sb.append("IMAP login performed...").append(lineSeparator);
+                    sb.append("Queued in cache: ").append(MailAccess.getMailAccessCache().numberOfMailAccesses(session, accountId));
+                    if (Log.appendTraceToMessage()) {
+                        sb.append(lineSeparator);
+                        appendStackTrace(new Throwable().getStackTrace(), lineSeparator, sb);
+                        sb.append(lineSeparator).append(lineSeparator);
+                        LOG.debug(sb.toString());
+                    } else {
+                        sb.append(lineSeparator).append(lineSeparator);
+                        LOG.debug(sb.toString(), new Throwable());
+                    }
+                }
                 final long currentValidity = getCurrentValidity(accountId, session);
                 imapStore.setValidity(currentValidity);
                 validity = currentValidity;
@@ -1467,4 +1485,36 @@ public final class IMAPAccess extends MailAccess<IMAPFolderStorage, IMAPMessageS
         return isWhitespace;
     }
 
+    private static final int MAX_STACK_TRACE_ELEMENTS = 1000;
+
+    private static void appendStackTrace(final StackTraceElement[] trace, final String lineSeparator, final com.openexchange.java.StringAllocator sb) {
+        if (null == trace) {
+            return;
+        }
+        final int length = (MAX_STACK_TRACE_ELEMENTS <= trace.length) ? MAX_STACK_TRACE_ELEMENTS : trace.length;
+        for (int i = 0; i < length; i++) {
+            final StackTraceElement ste = trace[i];
+            final String className = ste.getClassName();
+            if (null != className) {
+                sb.append("    at ").append(className).append('.').append(ste.getMethodName());
+                if (ste.isNativeMethod()) {
+                    sb.append("(Native Method)");
+                } else {
+                    final String fileName = ste.getFileName();
+                    if (null == fileName) {
+                        sb.append("(Unknown Source)");
+                    } else {
+                        final int lineNumber = ste.getLineNumber();
+                        sb.append('(').append(fileName);
+                        if (lineNumber >= 0) {
+                            sb.append(':').append(lineNumber);
+                        }
+                        sb.append(')');
+                    }
+                }
+                sb.append(lineSeparator);
+            }
+        }
+    }
+
 }
