@@ -71,6 +71,7 @@ import com.openexchange.imap.cache.NamespaceFoldersCache;
 import com.openexchange.imap.cache.RootSubfolderCache;
 import com.openexchange.imap.config.IMAPConfig;
 import com.openexchange.imap.services.IMAPServiceRegistry;
+import com.openexchange.log.Log;
 import com.openexchange.mail.MailExceptionCode;
 import com.openexchange.mail.MailSessionCache;
 import com.openexchange.mail.MailSessionParameterNames;
@@ -454,9 +455,15 @@ public class IMAPDefaultFolderChecker {
         } catch (final OXException e) {
             final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(1024);
             sb.append("Couldn't check default folder: ");
-            sb.append((null == fullName ? (prefix + name) : fullName)).append("\n\n");
-            appendStackTrace(e.getStackTrace(), sb, new ClassNameMatcher(IMAPDefaultFolderChecker.class.getSimpleName()));
-            LOG.warn(sb.toString());
+            sb.append((null == fullName ? (prefix + name) : fullName));
+            if (Log.appendTraceToMessage()) {
+                final String lineSeparator = System.getProperty("line.separator");
+                sb.append(lineSeparator).append(lineSeparator);
+                appendStackTrace(e.getStackTrace(), sb, new ClassNameMatcher(IMAPDefaultFolderChecker.class.getSimpleName()), lineSeparator);                        
+                LOG.warn(sb.toString());
+            } else {
+                LOG.warn(sb.toString(), e);
+            }
             setDefaultMailFolder(index, null, cache);
             e.setCategory(Category.CATEGORY_WARNING);
             imapStore.getImapAccess().addWarnings(Collections.singleton(e));
@@ -477,18 +484,30 @@ public class IMAPDefaultFolderChecker {
                  */
                 final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(1024);
                 sb.append("Couldn't check default folder due to exceeded quota restrictions: ");
-                sb.append((null == fullName ? (prefix + name) : fullName)).append("\n\n");
-                appendStackTrace(e.getStackTrace(), sb, new ClassNameMatcher(IMAPDefaultFolderChecker.class.getSimpleName()));
-                LOG.warn(sb.toString());
+                sb.append((null == fullName ? (prefix + name) : fullName));
+                if (Log.appendTraceToMessage()) {
+                    final String lineSeparator = System.getProperty("line.separator");
+                    sb.append(lineSeparator).append(lineSeparator);
+                    appendStackTrace(e.getStackTrace(), sb, new ClassNameMatcher(IMAPDefaultFolderChecker.class.getSimpleName()), lineSeparator);                        
+                    LOG.warn(sb.toString());
+                } else {
+                    LOG.warn(sb.toString(), e);
+                }
                 setDefaultMailFolder(index, null, cache);
                 final OXException warning = MimeMailException.handleMessagingException(e, imapConfig, session).setCategory(Category.CATEGORY_WARNING);
                 imapStore.getImapAccess().addWarnings(Collections.singleton(warning));
             } else {
                 final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(1024);
                 sb.append("Couldn't check default folder: ");
-                sb.append((null == fullName ? (prefix + name) : fullName)).append("\n\n");
-                appendStackTrace(e.getStackTrace(), sb, new ClassNameMatcher(IMAPDefaultFolderChecker.class.getSimpleName()));
-                LOG.warn(sb.toString());
+                sb.append((null == fullName ? (prefix + name) : fullName));
+                if (Log.appendTraceToMessage()) {
+                    final String lineSeparator = System.getProperty("line.separator");
+                    sb.append(lineSeparator).append(lineSeparator);
+                    appendStackTrace(e.getStackTrace(), sb, new ClassNameMatcher(IMAPDefaultFolderChecker.class.getSimpleName()), lineSeparator);                        
+                    LOG.warn(sb.toString());
+                } else {
+                    LOG.warn(sb.toString(), e);
+                }
                 setDefaultMailFolder(index, null, cache);
                 final OXException warning = MimeMailException.handleMessagingException(e, imapConfig, session).setCategory(Category.CATEGORY_WARNING);
                 imapStore.getImapAccess().addWarnings(Collections.singleton(warning));
@@ -862,11 +881,10 @@ public class IMAPDefaultFolderChecker {
      * @param sb The builder
      * @param num The max. number of elements to append
      */
-    protected static void appendStackTrace(final StackTraceElement[] trace, final com.openexchange.java.StringAllocator sb, final StackTraceElementMatcher matcher) {
+    protected static void appendStackTrace(final StackTraceElement[] trace, final com.openexchange.java.StringAllocator sb, final StackTraceElementMatcher matcher, final String lineSeparator) {
         if (null == trace) {
             return;
         }
-        final String lineSeparator = System.getProperty("line.separator");
         for (int i = 0; i < trace.length && matcher.accepts(trace[i]); i++) {
             final StackTraceElement ste = trace[i];
             final String className = ste.getClassName();
